@@ -5,7 +5,8 @@ from django.conf import settings
 from django.apps import apps
 # from .tasks import extract_file, extract_models_callback
 # from celery.task import chord
-import multiprocessing
+# import multiprocessing
+from django.core import serializers
 
 
 def db_load(*args, **options):
